==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/usermanager/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 */
$lang['menu']                  = 'Gerenciamento de Usuários';
$lang['noauth']                = '(o gerenciamento de usuários não está disponível)';
$lang['nosupport']             = '(o gerenciamento de usuários não é suportado)';
$lang['badauth']               = 'mecanismo de autenticação inválido';
$lang['user_id']               = 'Usuário';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome real';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Excluir';
$lang['delete_selected']       = 'Excluir a seleção';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar esse usuário';
$lang['modify']                = 'Salvar as alterações';
$lang['search']                = 'Pesquisar';
$lang['search_prompt']         = 'Executar a pesquisa';
$lang['clear']                 = 'Limpar o filtro de pesquisa';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Exibindo usuários %1$d-%2$d de %3$d encontrados. %4$d usuários no total.';
$lang['nonefound']             = 'Nenhum usuário encontrado. %d usuários no total.';
$lang['delete_ok']             = '%d usuários excluídos';
$lang['delete_fail']           = 'Erro na exclusão de %d usuários.';
$lang['update_ok']             = 'Usuário atualizado com sucesso';
$lang['update_fail']           = 'Não foi possível atualizar o usuário';
$lang['update_exists']         = 'Não foi possível mudar o nome do usuário. O nome especificado (%s) já existe (as outras mudanças serão aplicadas).';
$lang['start']                 = 'primeira';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'próxima';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'O usuário selecionado não foi encontrado, ele foi excluído ou teve o seu nome modificado.';
$lang['user_notify']           = 'Notificar o usuário';
$lang['note_notify']           = 'E-mails de notificação são enviados apenas se o usuário digitar uma nova senha.';
$lang['note_group']            = 'Novos usuários serão adicionados ao grupo padrão (%s), caso nenhum grupo seja especificado.';
$lang['note_pass']             = 'A senha será gerada automaticamente se o campo for deixado em branco e a notificação de usuário estiver habilitada.';
$lang['add_ok']                = 'O usuário foi adicionado com sucesso';
$lang['add_fail']              = 'O usuário não foi adicionado';
$lang['notify_ok']             = 'O e-mail de notificação foi enviado';
$lang['notify_fail']           = 'Não foi possível enviar o e-mail de notificação';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/usermanager/lang/pt-br/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 * @author Victor Westmann <victor.westmann@gmail.com>
 * @author Leone Lisboa Magevski <leone1983@gmail.com>
 * @author Dário Estevão <darioems@gmail.com>
 * @author Juliano Marconi Lanigra <juliano.marconi@gmail.com>
 */
$lang['menu']                  = 'Gerenciamento de Usuários';
$lang['noauth']                = '(o gerenciamento de usuários não está disponível)';
$lang['nosupport']             = '(o gerenciamento de usuários não é suportado)';
$lang['badauth']               = 'mecanismo de autenticação inválido';
$lang['user_id']               = 'Usuário';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome real';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Excluir';
$lang['delete_selected']       = 'Excluir a seleção';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar esse usuário';
$lang['modify']                = 'Salvar as alterações';
$lang['search']                = 'Pesquisar';
$lang['search_prompt']         = 'Executar a pesquisa';
$lang['clear']                 = 'Limpar o filtro de pesquisa';
$lang['filter']                = 'Filtro';
$lang['export_all']            = 'Exportar Todos Usuários (CSV)';
$lang['export_filtered']       = 'Exportar lista de Usuários Filtrados (CSV)';
$lang['import']                = 'Importar Novos Usuários';
$lang['line']                  = 'Linha Nº.';
$lang['error']                 = 'Mensagem de Erro';
$lang['summary']               = 'Exibindo usuários %1$d-%2$d de %3$d encontrados. %4$d usuários no total.';
$lang['nonefound']             = 'Nenhum usuário encontrado. %d usuários no total.';
$lang['delete_ok']             = '%d usuários excluídos';
$lang['delete_fail']           = 'Erro na exclusão de %d usuários.';
$lang['update_ok']             = 'Usuário atualizado com sucesso';
$lang['update_fail']           = 'Não foi possível atualizar o usuário';
$lang['update_exists']         = 'Não foi possível mudar o nome do usuário. O nome especificado (%s) já existe (as outras mudanças serão aplicadas).';
$lang['start']                 = 'primeira';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'próxima';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'O usuário selecionado não foi encontrado, ele foi excluído ou teve o seu nome modificado.';
$lang['user_notify']           = 'Notificar o usuário';
$lang['note_notify']           = 'E-mails de notificação são enviados apenas se o usuário digitar uma nova senha.';
$lang['note_group']            = 'Novos usuários serão adicionados ao grupo padrão (%s), caso nenhum grupo seja especificado.';
$lang['note_pass']             = 'A senha será gerada automaticamente se o campo for deixado em branco e a notificação de usuário estiver habilitada.';
$lang['add_ok']                = 'O usuário foi adicionado com sucesso';
$lang['add_fail']              = 'O usuário não foi adicionado';
$lang['notify_ok']             = 'O e-mail de notificação foi enviado';
$lang['notify_fail']           = 'Não foi possível enviar o e-mail de notificação';
$lang['import_userlistcsv']    = 'Arquivo de lista de usuários (CSV):';
$lang['import_header']         = 'Importações Mais Recentes - Falhas';
$lang['import_success_count']  = 'Importação de Usuário: %d usuário (s) encontrado (s), %d importado (s) com sucesso.';
$lang['import_failure_count']  = 'Importação de Usuário: %d falhou. As falhas estão listadas abaixo.';
$lang['import_error_fields']   = 'Campos insuficientes, encontrado (s) %d, necessário 4.';
$lang['import_error_baduserid'] = 'Id do usuário não encontrado.';
$lang['import_error_badname']  = 'Nome errado';
$lang['import_error_badmail']  = 'Endereço de email errado';
$lang['import_error_upload']   = 'Falha na Importação: O arquivo csv não pode ser carregado ou está vazio.';
$lang['import_error_readfail'] = 'Falha na Importação: Habilitar para ler o arquivo a ser carregado.';
$lang['import_error_create']   = 'Habilitar para criar o usuário.';
$lang['import_notify_fail']    = 'Mensagem de notificação não pode ser enviada para o usuário importado, %s com email %s.';
$lang['import_downloadfailures'] = 'Falhas no Download como CSV para correção';
